Provides a framework to download, parse, and store text datasets on the disk and load them when needed. Includes various sentiment lexicons and labeled text data sets for classification and analysis.
Maintainer: Emil Hvitfeldt [email protected] (ORCID)
Other contributors:
Julia Silge [email protected] (ORCID) [contributor]
Useful links: